@@ -3,7 +3,7 @@
 #
 ################################################################################
 
-::Version::setSubversionId {$Id: loging.tcl 10183 2008-06-13 05:08:27Z kakaroto $}
+::Version::setSubversionId {$Id: loging.tcl 11713 2009-10-19 18:52:33Z billiob $}
 
 # TODO Implement some sort of log file size limit or date limit (remove any log entries older than date)
 # TODO Save to LOG (if logging disabled, allows to log certain conversations only)
@@ -446,11 +446,15 @@ namespace eval ::log {
 
 		set wname [::log::wname $email]
 
-		if { [catch {toplevel ${wname} -width 600 -height 400 -borderwidth 0 -highlightthickness 0 } res ] } {
-			raise ${wname}
-			focus ${wname}
-			wm deiconify ${wname}
+		if { [winfo exists $wname] } {
+		    raise ${wname}
+		    focus ${wname}
+		    wm deiconify ${wname}
+		    return 0
+		} else {
+		    if {[catch {toplevel ${wname} -width 600 -height 400 -borderwidth 0 -highlightthickness 0 } res ] } {
 			return 0
+		    }
 		}
 		
 		wm group ${wname} .
@@ -529,6 +533,7 @@ namespace eval ::log {
 		menu ${wname}.copypaste -tearoff 0 -type normal
 		${wname}.copypaste add command -label [trans copy] -command [list tk_textCopy ${wname}.blueframe.log.txt]
 		
+		pack $wname.buttons -side bottom -fill x -pady 3
 		pack $wname.top -side top -fill x
 		pack $wname.blueframe.log.ys -side right -fill y
 		pack $wname.blueframe.log.txt -side left -expand true -fill both
@@ -539,7 +544,6 @@ namespace eval ::log {
 		pack $wname.buttons.save -padx 0 -side right
 		pack $wname.buttons.clear -padx 0 -side right
 		pack $wname.buttons.find -padx 0 -side right
-		pack $wname.buttons -side bottom -fill x -pady 3
 		bind $wname <<Escape>> "destroy $wname"
 		bind ${wname}.blueframe.log.txt <<Button3>> "tk_popup ${wname}.copypaste %X %Y"
 		moveinscreen $wname 30
@@ -554,7 +558,16 @@ namespace eval ::log {
 
 		set contact_list [list]
 		foreach sDir $lDirs {
-			foreach sLogFile [glob -tails -nocomplain -types f -directory ${sDir} "*.cam"] {
+			foreach sLogFile [glob -tails -nocomplain -types f -directory ${sDir} "*.cam" "*.CAM"] {
+
+				#it's possible that if we move the cam files in another file system and then we import them, every extensions can be uppercased. So we have to convert *.CAM in *.cam. The same for dat files.
+				if {[file extension $sLogFile] eq ".CAM"} {
+					set filenoext "${sDir}/"
+					append filenoext [string range $sLogFile 0 end-4]
+					catch { [file rename "${filenoext}.CAM" "${filenoext}.cam"]}
+					catch { [file rename "${filenoext}.DAT" "${filenoext}.dat"]}
+				}
+
 				set sLogFile [ string range $sLogFile 0 [ expr { [string length $sLogFile] - 5 } ] ]
 				lappend contact_list $sLogFile
 			}
@@ -574,13 +587,17 @@ namespace eval ::log {
 		
 		set wname [::log::cam_wname $email]
 
-		if { [catch {toplevel ${wname} -borderwidth 0 -highlightthickness 0 } res ] } {
-			raise ${wname}
-			focus ${wname}
-			wm deiconify ${wname}
+		if { [winfo exists $wname] } {
+		    raise ${wname}
+		    focus ${wname}
+		    wm deiconify ${wname}
+		    return 0
+		} else {
+		    if { [catch {toplevel ${wname} -borderwidth 0 -highlightthickness 0 } res ] } {
 			return 0
+		    }
 		}
-		
+
 		wm group ${wname} .
 
 		if { [file exists [file join ${webcam_dir} ${email}.cam]] } {
@@ -673,9 +690,9 @@ namespace eval ::log {
 
 		#not using -command to avoid constantly changing while user is dragging it around
 		#interp alias {} imgseek {} ::CAMGUI::Seek $wname [file join ${webcam_dir} ${email}.cam]
-		bind $wname.position.slider <ButtonPress-1> "::CAMGUI::Pause $wname"
-		#bind $wname.position.slider <Button1-ButtonRelease> {imgseek [%W get]}
-		bind $wname.position.slider <ButtonRelease-1> [list ::CAMGUI::Resume $wname [file join ${webcam_dir} ${email}.cam]]
+		bind $wname.position.slider <<Button1-Press>> "::CAMGUI::Pause $wname"
+		#bind $wname.position.slider <<Button1>> {imgseek [%W get]}
+		bind $wname.position.slider <<Button1>> [list ::CAMGUI::Resume $wname [file join ${webcam_dir} ${email}.cam]]
 
 		
 		pack $wname.top -side top -fill x
@@ -830,10 +847,10 @@ namespace eval ::log {
 
 	proc wname {email} {
 
-		set wname [split $email "@ ."]
+		set wname [split $email "@ .:"]
 		set wname [join $wname "_"]
 		set wname ".${wname}_hist"
-		return $wname
+		return [string tolower $wname]
 	}
 
 	proc cam_wname {email} {
@@ -841,7 +858,7 @@ namespace eval ::log {
 		set wname [split $email "@ ."]
 		set wname [join $wname "_"]
 		set wname ".${wname}_cam"
-		return $wname
+		return [string tolower $wname]
 	}
 
 	proc LogsByDate {wname email} {
@@ -1197,6 +1214,7 @@ namespace eval ::log {
 
 		set loglines [split $logvar "\n"]
 		set result [list]
+		set color grey
 		foreach line $loglines {
 			incr nbline
 			set aidx 0
@@ -1210,11 +1228,22 @@ namespace eval ::log {
 					# The color is indicated by the 6 fingers after it
 					if {[string index $line [expr {$aidx + 3}]] == "C"} {
 						set color [string range $line [expr {$aidx + 4}] [expr {$aidx + 9}]]
-						${wname}.blueframe.log.txt tag configure C_$nbline -foreground "#$color"
-						set color "C_$nbline"
-						incr aidx 10
-						# Else, it is the system with LNOR, LGRA...
+						if { [catch {${wname}.blueframe.log.txt tag configure C_$nbline -foreground "#$color"}]} {
+							# invalid color, maybe the file is corrupted... skip only digits
+							incr aidx 4
+							for {set i 0} { $i < 6 } { incr i } {
+								if { ![string is digit [string range $line $aidx $aidx]] } {
+									break
+								}
+								incr aidx
+							}
+							set color "normal"
+						} else {
+							set color "C_$nbline"
+							incr aidx 10
+						}
 					} else {
+						# Else, it is the system with LNOR, LGRA...
 						if {[string range $line $aidx [expr {$aidx + 6}]] == "\|\"LTIME"  } {
 							#it is a time in [clock seconds]
 							incr aidx 7
@@ -1227,8 +1256,8 @@ namespace eval ::log {
 							set aidx $sidx
 							incr aidx 1
 						} else {
-						set color [string range $line [expr {$aidx + 3}] [expr {$aidx + 5}]]
-						incr aidx 6
+							set color [string range $line [expr {$aidx + 3}] [expr {$aidx + 5}]]
+							incr aidx 6
 						}
 					}
 					set bidx [string first "\|\"L" $line $aidx]
@@ -1392,7 +1421,7 @@ namespace eval ::log {
 					set aidx $bidx
 				} else {
 					append str [string range $logvar $aidx end]
-					puts -nonewline $fileid str
+					puts -nonewline $fileid $str
 					break
 				}
 				set str ""
@@ -1765,48 +1794,31 @@ namespace eval ::log {
 	#///////////////////////////////////////////////////////////////////////////////
 	# Sort the contact by the log size
 
-	proc sortalllog { } {
-
+	proc getcontactlogsize { email {month "."} {include_subdirs 1}} {
 		global log_dir
 
-		set contactlist [::abook::getAllContacts]
-		
-		set contactsize [list]
-
-		set months "0 January February March April May June July August September October November December"
-		
-		foreach email $contactlist {
+		set file [file join ${log_dir} ${month} ${email}.log]
 			
+		if { [file exists $file] == 1 } {
+			set size [file size $file]
+		} else {
 			set size 0
-			
-			set file "[file join ${log_dir} ${email}.log]"
-			
-			if { [file exists $file] == 1 } {
-				set size [file size $file]
+		}
+		
+		if {$include_subdirs } {
+			foreach file [glob -nocomplain -types f [file join ${log_dir} * ${email}.log]] {
+				incr size [file size $file]
 			}
+		}
 			
-			if { [::config::getKey logsbydate] == 1 } {
-				foreach date [glob -nocomplain -types f [file join ${log_dir} * ${email}.log]] {
-					set date [getfilename [file dirname $date]]
-					if { [catch { clock scan "1 $date"}] == 0 } {
-						set date [clock scan "1 $date"]
-						set month [clock format $date -format "%m"]
-						if { [string range $month 0 0] == "0" } {
-							set month [string range $month 1 1]
-						}
-						set month "[lindex $months $month]"
-						set year "[clock format $date -format "%Y"]"
-						set date "$month $year"
-						set file [file join ${log_dir} ${date} ${email}.log]
-						if { [file exists $file] } {
-							incr size [file size $file]
-						}
-					}
-				}
-			}
-			
-			set contactsize [lappend contactsize [list $email $size]]
-			
+		return $size
+	}
+
+	proc getlogsizes { {month "."} {include_subdirs 1} } {
+		set contactsize [list]
+		
+		foreach email [::abook::getAllContacts] {
+			lappend contactsize [list $email [::log::getcontactlogsize $email $month $include_subdirs]]
 		}
 		
 		set contactsize [lsort -integer -index 1 -decreasing $contactsize]
@@ -1815,62 +1827,20 @@ namespace eval ::log {
 		
 	}
 
+	proc sortalllog { } {
+		return [::log::getlogsizes]
+		
+	}
+
+	proc sortmonthlog { month } {
+		return [::log::getlogsizes $month 0]
+	}
+
 
 	proc sortthismonthlog { } {
-
-		global log_dir
-
-		set contactlist [::abook::getAllContacts]
-
-		foreach email $contactlist {
-
-			set file [file join ${log_dir} ${email}.log]
-
-			if { [file exists $file] } {
-				set size [file size $file]
-			} else {
-				set size 0
-			}
-
-			set contactsize [lappend contactsize [list $email $size]]
-
-		}
-
-		set contactsize [lsort -integer -index 1 -decreasing $contactsize]
-		
-		return $contactsize
-
+		return [::log::getlogsizes . 0]
 	}
 
-	proc sortmonthlog { month } {
-
-		global log_dir
-		
-		set contactlist [::abook::getAllContacts]
-		
-		set contactsize [list]
-		
-		foreach email $contactlist {
-			
-			set file [file join ${log_dir} ${month} ${email}.log]
-			
-			if { [file exists $file] } {
-				set size [file size $file]
-			} else {
-				set size 0
-			}
-			
-			set contactsize [lappend contactsize [list $email $size]]
-			
-		}
-		
-		set contactsize [lsort -integer -index 1 -decreasing $contactsize]
-		
-		return $contactsize
-		
-	}
-
-
 
 	proc getAllDates { } {
 
