@@ -261,7 +261,7 @@ namespace eval ::Nudge {
 		set maxw [expr {[::skin::getKey notifwidth]-20}]
 		set nickname [trunc $nick . $maxw splainf]
 		#Show the notification
-		::amsn::notifyAdd "Nudge\n[trans nudge $nickname]." "::amsn::chatUser $email" "" plugins
+		::amsn::notifyAdd [trans nudge $nickname] "::amsn::chatUser $email" "" plugins
 		::Nudge::log "Notify window created"
 	}
 
@@ -344,11 +344,14 @@ namespace eval ::Nudge {
 				-background [::skin::getColor background2] -highlightthickness 0 -borderwidth 0 \
 				-highlightbackground [::skin::getColor background2] -activebackground [::skin::getColor background2]\
 			} else {
-				label $nudgebutton -image [::skin::loadPixmap nudgebutton] -relief flat -padx 0 \
+				button $nudgebutton -image [::skin::loadPixmap nudgebutton] -relief flat -padx 0 \
 				-background [::skin::getKey buttonbarbg] -highlightthickness 0 -borderwidth 0 \
+				-command "after 1 ::Nudge::send_via_queue $newvar(window_name)" \
 				-highlightbackground [::skin::getKey buttonbarbg] -activebackground [::skin::getKey buttonbarbg]\
 			}
-			bind $nudgebutton <<Button1>> "after 1 ::Nudge::send_via_queue $newvar(window_name)"
+			if {[::Nudge::version_094]} {
+				bind $nudgebutton <<Button1>> "after 1 ::Nudge::send_via_queue $newvar(window_name)"
+			}
 			#Configure hover button
 			bind $nudgebutton <Enter> "$nudgebutton configure -image [::skin::loadPixmap nudgebutton_hover]"
 			bind $nudgebutton <Leave> "$nudgebutton configure -image [::skin::loadPixmap nudgebutton]"
@@ -575,7 +578,10 @@ namespace eval ::Nudge {
 	proc check_clientid {email} {
 		::Nudge::log "Verify if contact is using MSN 7.0 protocol"
 
-		set clientid [::abook::getContactData $email clientid]
+		set clientcaps [::abook::getContactData $email clientid]
+		set clientcaps [split $clientcaps ":"]
+		set clientid [lindex $clientcaps 0]
+		# set extra [lindex $clientcaps 1]
 
 		::Nudge::log "Clientid is $clientid"
 
@@ -673,11 +679,14 @@ namespace eval ::Nudge {
 				-background [::skin::getColor background2] -highlightthickness 0 -borderwidth 0 \
 				-highlightbackground [::skin::getColor background2] -activebackground [::skin::getColor background2]\
 			} else {
-				label $nudgebutton -image [::skin::loadPixmap $nudgeimg] -relief flat -padx 0 \
+				button $nudgebutton -image [::skin::loadPixmap $nudgeimg] -relief flat -padx 0 \
 				-background [::skin::getKey buttonbarbg] -highlightthickness 0 -borderwidth 0 \
+				-command  "after 1 ::Nudge::blocknudge $chatid $nudgebutton" \
 				-highlightbackground [::skin::getKey buttonbarbg] -activebackground [::skin::getKey buttonbarbg]\
 			}
-			bind $nudgebutton <<Button1>> "after 1 ::Nudge::blocknudge $chatid $nudgebutton"
+			if {[::Nudge::version_094]} {
+				bind $nudgebutton <<Button1>> "after 1 ::Nudge::blocknudge $chatid $nudgebutton"
+			}
 			
 			#Define baloon info
 			set_balloon $nudgebutton "$::Nudge::language(block_nudge)"
