@@ -1,5 +1,5 @@
 
-::Version::setSubversionId {$Id: smileys.tcl 10040 2008-05-28 15:08:53Z baaazen $}
+::Version::setSubversionId {$Id: smileys.tcl 11713 2009-10-19 18:52:33Z billiob $}
 
 if { $initialize_amsn == 1 } {
 	global smileys_drawn
@@ -196,20 +196,19 @@ namespace eval ::smiley {
 			set emotion($field_sort) [string trim $sdata($field)]
 		}
 
-
 		#Create the image now and store it   ;# $emotion(name) is unique as we store the emoticon in the array under this name (cfr infra)
-		if { [catch { image create photo emoticonCustom_std_$emotion(text) -file $emotion(file) -format cximage } emotion(image_name) ] } {
+		if { [catch { image create photo emoticonCustom_std_$emotion(text) -file [PathRelToAbs $emotion(file)] -format cximage } emotion(image_name) ] } {
 			status_log "Error when creating image for emoticon $emotion(name) : $emotion(image_name)"
 
 			#error loading emoticon, just flag it as unreachable
 			set emotion(reachable) 0
 		} else {
-			set emotion(preview) [image create photo emoticonCustom_preview_$emotion(text)]
-			$emotion(preview) copy emoticonCustom_std_$emotion(text)
 			set emotion(reachable) 1
 
 			# Make sure the smiley is max 50x50
 			::smiley::resizeCustomSmiley emoticonCustom_std_$emotion(text)
+			
+			update
 		}
 		
 		#Store the emoticon data in the custom_emoticons array
@@ -321,10 +320,10 @@ namespace eval ::smiley {
 					
 					set animated [expr {[info exists emotion(animated)] && [is_true $emotion(animated)]}]
 					if { $contact_list == 0 && [info exists emotion(sound)] && $emotion(sound) != "" } {
-						set sound $emotion(sound)
+						set sound [PathRelToAbs $emotion(sound)]
 					} else { set sound "" }
 					set image_name $emotion(image_name)
-					set image_file $emotion(file)
+					set image_file [PathRelToAbs $emotion(file)]
 					
 					
 					array unset emotion
@@ -466,7 +465,7 @@ namespace eval ::smiley {
 			#this procedure without all smileys having been created
 			catch { 
 				#TODO: Improve this now we know about quoting a bit more?
-				bind $w.c.$temp <Button1-ButtonRelease> "catch {[list $text insert insert $symbol]\; wm state $w withdrawn} res" 
+				bind $w.c.$temp <<Button1>> "catch {[list $text insert insert $symbol]\; wm state $w withdrawn; event generate $text <KeyRelease>} res" 
 			}
 			
 			incr temp
@@ -484,16 +483,10 @@ namespace eval ::smiley {
 			catch { 
 				if { $emotion(reachable) == 1 } {
 					#TODO: Improve this now we know about quoting a bit more?
-					bind $w.c.$temp <Button1-ButtonRelease> "catch {[list $text insert insert $symbol]\; wm state $w withdrawn} res" 
+					bind $w.c.$temp <<Button1>> "catch {[list $text insert insert $symbol]\; wm state $w withdrawn; event generate $text <KeyRelease>} res" 
 				}
 				#Add binding for custom emoticons
-				if { [OnMac] } {
-					
-					bind $w.c.$temp <Button2-ButtonRelease> [list ::smiley::editCustomEmotion $name]
-					bind $w.c.$temp <Control-ButtonRelease> [list ::smiley::editCustomEmotion $name]
-				} else {
-					bind $w.c.$temp <Button3-ButtonRelease> [list ::smiley::editCustomEmotion $name]
-				}
+				bind $w.c.$temp <<Button3>> [list ::smiley::editCustomEmotion $name]
 			}
 			
 			incr temp
@@ -519,13 +512,14 @@ namespace eval ::smiley {
 
 	#//////////////////////////////////////////////////////////////////
 	#proc that changes a string into a list with seperated text/smileys
-	proc parseMessageToList { name {contact_list 0} {include_custom 0} } {
+	# TODO : WTF! This is a copy paste of substSmiley.. code should NOT be duplicated!
+	# TODO : contact_list variable is about playing sound, not about including smileys..
+	proc parseMessageToList { name {contact_list 0} {play_sounds 0} {include_custom 0} } {
 		global emotions
 		global custom_emotions
 		variable sortedemotions
 
-		#This is a poor place for sort smileys should be done only when adding new smileys to the list?
-		#SortSmileys
+		SortSmileys
 
 		set llength [llength $name]
 		set l $name
@@ -534,7 +528,6 @@ namespace eval ::smiley {
 		set foreachlist [list ]
 
 		if { [::config::getKey listsmileys] || !$contact_list } {
-			SortSmileys
 			set foreachlist [concat $foreachlist $sortedemotions]
 		}
 
@@ -564,19 +557,19 @@ namespace eval ::smiley {
 					}
 					
 					if { [info exists emotion(casesensitive)] && [is_true $emotion(casesensitive)]} {
-						set nocase "-exact"
+						set nocase 0
 					} else {
-						set nocase "-nocase"
+						set nocase 1
 					}
 		
 					set animated [expr {[info exists emotion(animated)] && [is_true $emotion(animated)]}]
-					if { $contact_list == 0 && [info exists emotion(sound)] && $emotion(sound) != "" } {
-						set sound $emotion(sound)
+					if { $play_sounds && [info exists emotion(sound)] && $emotion(sound) != "" } {
+						set sound [PathRelToAbs $emotion(sound)]
 					} else {
 						set sound ""
 					}
 					set image_name $emotion(image_name)
-					set image_file $emotion(file)
+					set image_file [PathRelToAbs $emotion(file)]
 		
 		
 					array unset emotion
@@ -600,7 +593,7 @@ namespace eval ::smiley {
 				}
 	
 				set animated [ValueForSmiley $emotion_name animated 1]
-				if { $contact_list == 0 && [ValueForSmiley $emotion_name sound] != "" } {
+				if { $play_sounds && [ValueForSmiley $emotion_name sound] != "" } {
 					set sound [ValueForSmiley $emotion_name sound]
 				} else {
 					set sound ""
@@ -767,7 +760,7 @@ namespace eval ::smiley {
 			set animated [expr {$emotion(animated) && [::config::getKey animatedsmileys 0]}]
 			
 			CreateSmileyInMenu $w.c $cols $rows $smiw $smih \
-				$emot_num $name [lindex $emotion(text) 0] $emotion(preview) $emotion(file) $animated $emotion(reachable)
+				$emot_num $name [lindex $emotion(text) 0] $emotion(image_name) [PathRelToAbs $emotion(file)] $animated $emotion(reachable)
 	
 			incr emot_num
 		}
@@ -776,7 +769,7 @@ namespace eval ::smiley {
 		label $w.c.custom_new -text "[trans custom_new]"  -background [$w.c cget -background] -font sboldf
 		bind $w.c.custom_new <Enter> [list $w.c.custom_new configure -relief raised]
 		bind $w.c.custom_new <Leave> [list $w.c.custom_new configure -relief flat]
-		bind $w.c.custom_new <Button1-ButtonRelease> "::smiley::newCustomEmoticonGUI; wm state $w withdrawn"
+		bind $w.c.custom_new <<Button1>> "::smiley::newCustomEmoticonGUI; wm state $w withdrawn"
 		
 		set ypos [expr {(($rows-1)*$smih + ($smih/2))}]
 		$w.c create window  0 $ypos -window $w.c.custom_new -width [expr {$x_geo - 2}] -height $smih -anchor w
@@ -959,7 +952,12 @@ namespace eval ::smiley {
 		
 		foreach element [list name file animated sound casesensitive] {
 			if {[info exists emotion($element)]} {
-				set new_custom_cfg($element) $emotion($element)
+				if {$element == "file" || $element == "sound"} {
+					#restore absolute path
+					set new_custom_cfg($element) [PathRelToAbs $emotion($element)]
+				} else {
+					set new_custom_cfg($element) $emotion($element)
+				}
 			} else {
 				set new_custom_cfg($element) ""
 			}
@@ -1089,9 +1087,12 @@ namespace eval ::smiley {
 			#Don't care of extension : as the smiley is animated TkCximage will save to GIF format
 			set filetail_noext [filenoext [file tail "$new_custom_cfg(file)"]]
 			set destfile [file join $HOME smileys $filetail_noext]
-			::picture::Convert [::skin::GetSkinFile smileys "$new_custom_cfg(file)"] "${destfile}.png"
-			set file "${destfile}.png"
-			if { ![file exists $file] } { set file "" }
+			if { [catch {file copy -force [::skin::GetSkinFile smileys "$new_custom_cfg(file)"] "${destfile}.png"}]} {
+				set file ""
+			} else {
+				set file "${destfile}.png"
+				if { ![file exists $file] } { set file "" }
+			}
 		}
 		
 		if { $file == "" } {
@@ -1127,8 +1128,6 @@ namespace eval ::smiley {
 		
 		
 		set emotion(image_name) [image create photo emoticonCustom_std_$emotion(text) -file $emotion(file) -format cximage]
-		set emotion(preview) [image create photo emoticonCustom_preview_$emotion(text)]
-		$emotion(preview) copy emoticonCustom_std_$emotion(text)
 
 		set custom_emotions($name) [array get emotion]
 
@@ -1224,12 +1223,20 @@ namespace eval ::smiley {
 
 		unset custom_emotions
 	}
+	proc PurgeUnreachables { } {
+		global custom_emotions
+		foreach name [array names custom_emotions] {
+			array set emotion [set custom_emotions($name)]
+			if {$emotion(reachable) == 0 } {
+				::smiley::NewCustomEmoticonGUI_Delete $name
+			}
+		}
+	}
 
 }
 
 
 
-
 #///////////////////////////////////////////////////////////////////////////////
 # proc is_true { data }
 #
@@ -1362,7 +1369,7 @@ proc process_custom_smileys_SB { txt {animated 0} } {
 		foreach symbol [encoding convertto identity $emotion(text)] {
 			set symbol2 [string toupper $symbol]
 		
-			set file $emotion(file)
+			set file [PathRelToAbs $emotion(file)]
 			if { ($animated && ([ info exists emotion(animated) ] && [ is_true $emotion(animated) ])) ||
 			     (!$animated && (! [ info exists emotion(animated) ] || ! [ is_true $emotion(animated) ]))} {
 				if { [info exists emotion(casesensitive)] && [is_true $emotion(casesensitive)] } {
